Index: components/web_view/web_view_impl.cc |
diff --git a/components/web_view/web_view_impl.cc b/components/web_view/web_view_impl.cc |
index 908fe7c9c64023e417f1c231f6233bdb7f7360a7..21eeabef32e49cf55ade8a76a47a8176d3b94097 100644 |
--- a/components/web_view/web_view_impl.cc |
+++ b/components/web_view/web_view_impl.cc |
@@ -51,7 +51,7 @@ |
content_->RemoveObserver(this); |
if (root_) { |
root_->RemoveObserver(this); |
- mus::ScopedViewPtr::DeleteViewOrViewManager(root_); |
+ mojo::ScopedViewPtr::DeleteViewOrViewManager(root_); |
} |
} |
@@ -109,7 +109,7 @@ |
void WebViewImpl::GetViewTreeClient( |
mojo::InterfaceRequest<mojo::ViewTreeClient> view_tree_client) { |
- mus::ViewTreeConnection::Create(this, view_tree_client.Pass()); |
+ mojo::ViewTreeConnection::Create(this, view_tree_client.Pass()); |
} |
void WebViewImpl::GoBack() { |
@@ -138,9 +138,9 @@ |
} |
//////////////////////////////////////////////////////////////////////////////// |
-// WebViewImpl, mus::ViewTreeDelegate implementation: |
- |
-void WebViewImpl::OnEmbed(mus::View* root) { |
+// WebViewImpl, mojo::ViewTreeDelegate implementation: |
+ |
+void WebViewImpl::OnEmbed(mojo::View* root) { |
// We must have been granted embed root priviledges, otherwise we can't |
// Embed() in any descendants. |
DCHECK(root->connection()->IsEmbedRoot()); |
@@ -157,14 +157,14 @@ |
OnLoad(); |
} |
-void WebViewImpl::OnConnectionLost(mus::ViewTreeConnection* connection) { |
+void WebViewImpl::OnConnectionLost(mojo::ViewTreeConnection* connection) { |
root_ = nullptr; |
} |
//////////////////////////////////////////////////////////////////////////////// |
-// WebViewImpl, mus::ViewObserver implementation: |
- |
-void WebViewImpl::OnViewBoundsChanged(mus::View* view, |
+// WebViewImpl, mojo::ViewObserver implementation: |
+ |
+void WebViewImpl::OnViewBoundsChanged(mojo::View* view, |
const mojo::Rect& old_bounds, |
const mojo::Rect& new_bounds) { |
if (view != content_) { |
@@ -175,7 +175,7 @@ |
} |
} |
-void WebViewImpl::OnViewDestroyed(mus::View* view) { |
+void WebViewImpl::OnViewDestroyed(mojo::View* view) { |
// |FrameTree| cannot outlive the content view. |
if (view == content_) { |
frame_tree_.reset(); |